@@ -31,7 +31,7 @@ else:
     import tomli as tomllib  # type: ignore[import]
 
 from ..labels import MANAGER_LABELS, MANAGER_PREFIX, PLATFORM_PREFIX
-from ..platforms import PLATFORM_GROUPS
+from ..platforms import PLATFORM_GROUPS, encoding_args
 from ..pool import pool
 
 """ Test all non-code artifacts depending on manager definitions.
@@ -51,13 +51,13 @@ PROJECT_ROOT = Path(__file__).parent.parent.parent
 def test_project_metadata():
     # Fetch general information about the project from pyproject.toml.
     toml_path = PROJECT_ROOT.joinpath("pyproject.toml").resolve()
-    toml_config = tomllib.loads(toml_path.read_text(encoding="utf-8"))
+    toml_config = tomllib.loads(toml_path.read_text(**encoding_args))
     # Check all managers are referenced in Python package keywords.
     assert set(pool.all_manager_ids).issubset(toml_config["tool"]["poetry"]["keywords"])
 
 
 def test_changelog():
-    content = PROJECT_ROOT.joinpath("changelog.md").read_text()
+    content = PROJECT_ROOT.joinpath("changelog.md").read_text(**encoding_args)
 
     assert content.startswith("# Changelog\n")
 
@@ -82,7 +82,9 @@ def test_changelog():
 
 def test_labeller_rules():
     # Extract list of extra labels.
-    content = PROJECT_ROOT.joinpath(".github/labels-extra.json").read_text()
+    content = PROJECT_ROOT.joinpath(".github/labels-extra.json").read_text(
+        **encoding_args
+    )
     assert content
 
     extra_labels = [lbl["name"] for lbl in json.loads(content)]
@@ -99,14 +101,6 @@ def test_labeller_rules():
         for lbl in canonical_labels
         if lbl.startswith(MANAGER_PREFIX) and "mpm" not in lbl
     }
-    print(repr(canonical_labels))
-    print(repr(MANAGER_PREFIX))
-    print(
-        [
-            (lbl, MANAGER_PREFIX, lbl.startswith(MANAGER_PREFIX))
-            for lbl in canonical_labels
-        ]
-    )
     assert canonical_managers
     canonical_platforms = {
         lbl for lbl in canonical_labels if lbl.startswith(PLATFORM_PREFIX)
@@ -116,7 +110,7 @@ def test_labeller_rules():
     # Extract rules from json blurb serialized into YAML.
     content = PROJECT_ROOT.joinpath(
         ".github/workflows/labeller-content-based.yaml"
-    ).read_text()
+    ).read_text(**encoding_args)
     assert "Naturalclar/issue-action" in content
     json_rules = load(content, Loader=Loader)["jobs"]["labeller"]["steps"][0]["with"][
         "parameters"
